﻿using System.Collections.Generic;
using System.Linq;
using TSLab.Script;
using TSLab.Script.Handlers;
using TSLab.Script.Helpers;


namespace TSLab.Community.Volatility
{
    //[HandlerCategory("Indicators")]
    public class Volatility : IBar2DoubleHandler
    {
        [HandlerParameter]
        public int EMAPeriod { get; set; }

        [HandlerParameter]
        public int ROCPeriod { get; set; }

        public IList<double> Execute(ISecurity source)
        {
            var highPrices = source.HighPrices;
            var lowPrices = source.LowPrices;
            var hlDiff = new List<double>(highPrices.Count);
            for (int i = 0; i < highPrices.Count; i++)
            {
                hlDiff.Add(highPrices[i] - lowPrices[i]);
            }

            var emaDiff = Series.EMA(hlDiff, EMAPeriod);

            var volatility = new double[highPrices.Count];
            for (int i = highPrices.Count - 1; i >= ROCPeriod; i--)
            {
                volatility[i] = (emaDiff[i] - emaDiff[i - ROCPeriod]) / emaDiff[i - ROCPeriod] * 100;
            }

            return volatility.ToList();
        }
    }

}
